from io import open
from setuptools import setup

version = '0.0.2'

setup(
    name = 'DLexam',
    version=version,

    author='OlegSh',
    author_email='9753124680sh@gmail.com',

    license='OlegSh' ,
    
    include_package_data=True,
    
    packages= ['DLexam']
)